# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from azure.core.exceptions import HttpResponseError
import msrest.serialization


class Dimension(msrest.serialization.Model):
    """Specifications of the Dimension of metrics.

    :param name: The public facing name of the dimension.
    :type name: str
    :param display_name: Localized friendly display name of the dimension.
    :type display_name: str
    :param internal_name: Name of the dimension as it appears in MDM.
    :type internal_name: str
    :param to_be_exported_for_shoebox: A Boolean flag indicating whether this dimension should be
     included for the shoebox export scenario.
    :type to_be_exported_for_shoebox: bool
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'display_name': {'key': 'displayName', 'type': 'str'},
        'internal_name': {'key': 'internalName', 'type': 'str'},
        'to_be_exported_for_shoebox': {'key': 'toBeExportedForShoebox', 'type': 'bool'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(Dimension, self).__init__(**kwargs)
        self.name = kwargs.get('name', None)
        self.display_name = kwargs.get('display_name', None)
        self.internal_name = kwargs.get('internal_name', None)
        self.to_be_exported_for_shoebox = kwargs.get('to_be_exported_for_shoebox', None)


class ErrorAdditionalInfo(msrest.serialization.Model):
    """The resource management error additional info.

    Variables are only populated by the server, and will be ignored when sending a request.

    :ivar type: The additional info type.
    :vartype type: str
    :ivar info: The additional info.
    :vartype info: any
    """

    _validation = {
        'type': {'readonly': True},
        'info': {'readonly': True},
    }

    _attribute_map = {
        'type': {'key': 'type', 'type': 'str'},
        'info': {'key': 'info', 'type': 'object'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(ErrorAdditionalInfo, self).__init__(**kwargs)
        self.type = None
        self.info = None


class ErrorDetail(msrest.serialization.Model):
    """The error detail.

    Variables are only populated by the server, and will be ignored when sending a request.

    :ivar code: The error code.
    :vartype code: str
    :ivar message: The error message.
    :vartype message: str
    :ivar target: The error target.
    :vartype target: str
    :ivar details: The error details.
    :vartype details: list[~azure.mgmt.webpubsub.models.ErrorDetail]
    :ivar additional_info: The error additional info.
    :vartype additional_info: list[~azure.mgmt.webpubsub.models.ErrorAdditionalInfo]
    """

    _validation = {
        'code': {'readonly': True},
        'message': {'readonly': True},
        'target': {'readonly': True},
        'details': {'readonly': True},
        'additional_info': {'readonly': True},
    }

    _attribute_map = {
        'code': {'key': 'code', 'type': 'str'},
        'message': {'key': 'message', 'type': 'str'},
        'target': {'key': 'target', 'type': 'str'},
        'details': {'key': 'details', 'type': '[ErrorDetail]'},
        'additional_info': {'key': 'additionalInfo', 'type': '[ErrorAdditionalInfo]'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(ErrorDetail, self).__init__(**kwargs)
        self.code = None
        self.message = None
        self.target = None
        self.details = None
        self.additional_info = None


class ErrorResponse(msrest.serialization.Model):
    """Common error response for all Azure Resource Manager APIs to return error details for failed operations. (This also follows the OData error response format.).

    :param error: The error object.
    :type error: ~azure.mgmt.webpubsub.models.ErrorDetail
    """

    _attribute_map = {
        'error': {'key': 'error', 'type': 'ErrorDetail'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(ErrorResponse, self).__init__(**kwargs)
        self.error = kwargs.get('error', None)


class EventHandler(msrest.serialization.Model):
    """Properties of event handler.

    All required parameters must be populated in order to send to Azure.

    :param url_template: Required. Gets or sets the EventHandler URL template. You can use a
     predefined parameter {hub} and {event} inside the template, the value of the EventHandler URL
     is dynamically calculated when the client request comes in.
     For example, UrlTemplate can be ``http://example.com/api/{hub}/{event}``. The host part can't
     contains parameters.
    :type url_template: str
    :param user_event_pattern: Gets or sets the matching pattern for event names.
     There are 3 kind of patterns supported:
    
     .. code-block::
    
        1. "*", it to matches any event name
        2. Combine multiple events with ",", for example "event1,event2", it matches event "event1"
     and "event2"
        3. The single event name, for example, "event1", it matches "event1".
    :type user_event_pattern: str
    :param system_events: Gets ot sets the list of system events.
    :type system_events: list[str]
    :param auth: Gets or sets the auth settings for an event handler. If not set, no auth is used.
    :type auth: ~azure.mgmt.webpubsub.models.UpstreamAuthSettings
    """

    _validation = {
        'url_template': {'required': True},
    }

    _attribute_map = {
        'url_template': {'key': 'urlTemplate', 'type': 'str'},
        'user_event_pattern': {'key': 'userEventPattern', 'type': 'str'},
        'system_events': {'key': 'systemEvents', 'type': '[str]'},
        'auth': {'key': 'auth', 'type': 'UpstreamAuthSettings'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(EventHandler, self).__init__(**kwargs)
        self.url_template = kwargs['url_template']
        self.user_event_pattern = kwargs.get('user_event_pattern', None)
        self.system_events = kwargs.get('system_events', None)
        self.auth = kwargs.get('auth', None)


class LiveTraceCategory(msrest.serialization.Model):
    """Live trace category configuration of a Microsoft.SignalRService resource.

    :param name: Gets or sets the live trace category's name.
     Available values: ConnectivityLogs, MessagingLogs.
     Case insensitive.
    :type name: str
    :param enabled: Indicates whether or the live trace category is enabled.
     Available values: true, false.
     Case insensitive.
    :type enabled: str
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'enabled': {'key': 'enabled', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(LiveTraceCategory, self).__init__(**kwargs)
        self.name = kwargs.get('name', None)
        self.enabled = kwargs.get('enabled', None)


class LiveTraceConfiguration(msrest.serialization.Model):
    """Live trace configuration of a Microsoft.SignalRService resource.

    :param enabled: Indicates whether or not enable live trace.
     When it's set to true, live trace client can connect to the service.
     Otherwise, live trace client can't connect to the service, so that you are unable to receive
     any log, no matter what you configure in "categories".
     Available values: true, false.
     Case insensitive.
    :type enabled: str
    :param categories: Gets or sets the list of category configurations.
    :type categories: list[~azure.mgmt.webpubsub.models.LiveTraceCategory]
    """

    _attribute_map = {
        'enabled': {'key': 'enabled', 'type': 'str'},
        'categories': {'key': 'categories', 'type': '[LiveTraceCategory]'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(LiveTraceConfiguration, self).__init__(**kwargs)
        self.enabled = kwargs.get('enabled', "false")
        self.categories = kwargs.get('categories', None)


class LogSpecification(msrest.serialization.Model):
    """Specifications of the Logs for Azure Monitoring.

    :param name: Name of the log.
    :type name: str
    :param display_name: Localized friendly display name of the log.
    :type display_name: str
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'display_name': {'key': 'displayName', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(LogSpecification, self).__init__(**kwargs)
        self.name = kwargs.get('name', None)
        self.display_name = kwargs.get('display_name', None)


class ManagedIdentity(msrest.serialization.Model):
    """A class represent managed identities used for request and response.

    Variables are only populated by the server, and will be ignored when sending a request.

    :param type: Represent the identity type: systemAssigned, userAssigned, None. Possible values
     include: "None", "SystemAssigned", "UserAssigned".
    :type type: str or ~azure.mgmt.webpubsub.models.ManagedIdentityType
    :param user_assigned_identities: Get or set the user assigned identities.
    :type user_assigned_identities: dict[str,
     ~azure.mgmt.webpubsub.models.UserAssignedIdentityProperty]
    :ivar principal_id: Get the principal id for the system assigned identity.
     Only be used in response.
    :vartype principal_id: str
    :ivar tenant_id: Get the tenant id for the system assigned identity.
     Only be used in response.
    :vartype tenant_id: str
    """

    _validation = {
        'principal_id': {'readonly': True},
        'tenant_id': {'readonly': True},
    }

    _attribute_map = {
        'type': {'key': 'type', 'type': 'str'},
        'user_assigned_identities': {'key': 'userAssignedIdentities', 'type': '{UserAssignedIdentityProperty}'},
        'principal_id': {'key': 'principalId', 'type': 'str'},
        'tenant_id': {'key': 'tenantId', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(ManagedIdentity, self).__init__(**kwargs)
        self.type = kwargs.get('type', None)
        self.user_assigned_identities = kwargs.get('user_assigned_identities', None)
        self.principal_id = None
        self.tenant_id = None


class ManagedIdentitySettings(msrest.serialization.Model):
    """Managed identity settings for upstream.

    :param resource: The Resource indicating the App ID URI of the target resource.
     It also appears in the aud (audience) claim of the issued token.
    :type resource: str
    """

    _attribute_map = {
        'resource': {'key': 'resource', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(ManagedIdentitySettings, self).__init__(**kwargs)
        self.resource = kwargs.get('resource', None)


class MetricSpecification(msrest.serialization.Model):
    """Specifications of the Metrics for Azure Monitoring.

    :param name: Name of the metric.
    :type name: str
    :param display_name: Localized friendly display name of the metric.
    :type display_name: str
    :param display_description: Localized friendly description of the metric.
    :type display_description: str
    :param unit: The unit that makes sense for the metric.
    :type unit: str
    :param aggregation_type: Only provide one value for this field. Valid values: Average, Minimum,
     Maximum, Total, Count.
    :type aggregation_type: str
    :param fill_gap_with_zero: Optional. If set to true, then zero will be returned for time
     duration where no metric is emitted/published.
     Ex. a metric that returns the number of times a particular error code was emitted. The error
     code may not appear
     often, instead of the RP publishing 0, Shoebox can auto fill in 0s for time periods where
     nothing was emitted.
    :type fill_gap_with_zero: str
    :param category: The name of the metric category that the metric belongs to. A metric can only
     belong to a single category.
    :type category: str
    :param dimensions: The dimensions of the metrics.
    :type dimensions: list[~azure.mgmt.webpubsub.models.Dimension]
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'display_name': {'key': 'displayName', 'type': 'str'},
        'display_description': {'key': 'displayDescription', 'type': 'str'},
        'unit': {'key': 'unit', 'type': 'str'},
        'aggregation_type': {'key': 'aggregationType', 'type': 'str'},
        'fill_gap_with_zero': {'key': 'fillGapWithZero', 'type': 'str'},
        'category': {'key': 'category', 'type': 'str'},
        'dimensions': {'key': 'dimensions', 'type': '[Dimension]'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(MetricSpecification, self).__init__(**kwargs)
        self.name = kwargs.get('name', None)
        self.display_name = kwargs.get('display_name', None)
        self.display_description = kwargs.get('display_description', None)
        self.unit = kwargs.get('unit', None)
        self.aggregation_type = kwargs.get('aggregation_type', None)
        self.fill_gap_with_zero = kwargs.get('fill_gap_with_zero', None)
        self.category = kwargs.get('category', None)
        self.dimensions = kwargs.get('dimensions', None)


class NameAvailability(msrest.serialization.Model):
    """Result of the request to check name availability. It contains a flag and possible reason of failure.

    :param name_available: Indicates whether the name is available or not.
    :type name_available: bool
    :param reason: The reason of the availability. Required if name is not available.
    :type reason: str
    :param message: The message of the operation.
    :type message: str
    """

    _attribute_map = {
        'name_available': {'key': 'nameAvailable', 'type': 'bool'},
        'reason': {'key': 'reason', 'type': 'str'},
        'message': {'key': 'message', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(NameAvailability, self).__init__(**kwargs)
        self.name_available = kwargs.get('name_available', None)
        self.reason = kwargs.get('reason', None)
        self.message = kwargs.get('message', None)


class NameAvailabilityParameters(msrest.serialization.Model):
    """Data POST-ed to the nameAvailability action.

    All required parameters must be populated in order to send to Azure.

    :param type: Required. The resource type. Can be "Microsoft.SignalRService/SignalR" or
     "Microsoft.SignalRService/webPubSub".
    :type type: str
    :param name: Required. The resource name to validate. e.g."my-resource-name".
    :type name: str
    """

    _validation = {
        'type': {'required': True},
        'name': {'required': True},
    }

    _attribute_map = {
        'type': {'key': 'type', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(NameAvailabilityParameters, self).__init__(**kwargs)
        self.type = kwargs['type']
        self.name = kwargs['name']


class NetworkACL(msrest.serialization.Model):
    """Network ACL.

    :param allow: Allowed request types. The value can be one or more of: ClientConnection,
     ServerConnection, RESTAPI.
    :type allow: list[str or ~azure.mgmt.webpubsub.models.WebPubSubRequestType]
    :param deny: Denied request types. The value can be one or more of: ClientConnection,
     ServerConnection, RESTAPI.
    :type deny: list[str or ~azure.mgmt.webpubsub.models.WebPubSubRequestType]
    """

    _attribute_map = {
        'allow': {'key': 'allow', 'type': '[str]'},
        'deny': {'key': 'deny', 'type': '[str]'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(NetworkACL, self).__init__(**kwargs)
        self.allow = kwargs.get('allow', None)
        self.deny = kwargs.get('deny', None)


class Operation(msrest.serialization.Model):
    """REST API operation supported by resource provider.

    :param name: Name of the operation with format: {provider}/{resource}/{operation}.
    :type name: str
    :param is_data_action: If the operation is a data action. (for data plane rbac).
    :type is_data_action: bool
    :param display: The object that describes the operation.
    :type display: ~azure.mgmt.webpubsub.models.OperationDisplay
    :param origin: Optional. The intended executor of the operation; governs the display of the
     operation in the RBAC UX and the audit logs UX.
    :type origin: str
    :param properties: Extra properties for the operation.
    :type properties: ~azure.mgmt.webpubsub.models.OperationProperties
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'is_data_action': {'key': 'isDataAction', 'type': 'bool'},
        'display': {'key': 'display', 'type': 'OperationDisplay'},
        'origin': {'key': 'origin', 'type': 'str'},
        'properties': {'key': 'properties', 'type': 'OperationProperties'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(Operation, self).__init__(**kwargs)
        self.name = kwargs.get('name', None)
        self.is_data_action = kwargs.get('is_data_action', None)
        self.display = kwargs.get('display', None)
        self.origin = kwargs.get('origin', None)
        self.properties = kwargs.get('properties', None)


class OperationDisplay(msrest.serialization.Model):
    """The object that describes a operation.

    :param provider: Friendly name of the resource provider.
    :type provider: str
    :param resource: Resource type on which the operation is performed.
    :type resource: str
    :param operation: The localized friendly name for the operation.
    :type operation: str
    :param description: The localized friendly description for the operation.
    :type description: str
    """

    _attribute_map = {
        'provider': {'key': 'provider', 'type': 'str'},
        'resource': {'key': 'resource', 'type': 'str'},
        'operation': {'key': 'operation', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(OperationDisplay, self).__init__(**kwargs)
        self.provider = kwargs.get('provider', None)
        self.resource = kwargs.get('resource', None)
        self.operation = kwargs.get('operation', None)
        self.description = kwargs.get('description', None)


class OperationList(msrest.serialization.Model):
    """Result of the request to list REST API operations. It contains a list of operations.

    :param value: List of operations supported by the resource provider.
    :type value: list[~azure.mgmt.webpubsub.models.Operation]
    :param next_link: The URL the client should use to fetch the next page (per server side
     paging).
     It's null for now, added for future use.
    :type next_link: str
    """

    _attribute_map = {
        'value': {'key': 'value', 'type': '[Operation]'},
        'next_link': {'key': 'nextLink', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(OperationList, self).__init__(**kwargs)
        self.value = kwargs.get('value', None)
        self.next_link = kwargs.get('next_link', None)


class OperationProperties(msrest.serialization.Model):
    """Extra Operation properties.

    :param service_specification: The service specifications.
    :type service_specification: ~azure.mgmt.webpubsub.models.ServiceSpecification
    """

    _attribute_map = {
        'service_specification': {'key': 'serviceSpecification', 'type': 'ServiceSpecification'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(OperationProperties, self).__init__(**kwargs)
        self.service_specification = kwargs.get('service_specification', None)


class PrivateEndpoint(msrest.serialization.Model):
    """Private endpoint.

    :param id: Full qualified Id of the private endpoint.
    :type id: str
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(PrivateEndpoint, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)


class PrivateEndpointACL(NetworkACL):
    """ACL for a private endpoint.

    All required parameters must be populated in order to send to Azure.

    :param allow: Allowed request types. The value can be one or more of: ClientConnection,
     ServerConnection, RESTAPI.
    :type allow: list[str or ~azure.mgmt.webpubsub.models.WebPubSubRequestType]
    :param deny: Denied request types. The value can be one or more of: ClientConnection,
     ServerConnection, RESTAPI.
    :type deny: list[str or ~azure.mgmt.webpubsub.models.WebPubSubRequestType]
    :param name: Required. Name of the private endpoint connection.
    :type name: str
    """

    _validation = {
        'name': {'required': True},
    }

    _attribute_map = {
        'allow': {'key': 'allow', 'type': '[str]'},
        'deny': {'key': 'deny', 'type': '[str]'},
        'name': {'key': 'name', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(PrivateEndpointACL, self).__init__(**kwargs)
        self.name = kwargs['name']


class Resource(msrest.serialization.Model):
    """The core properties of ARM resources.

    Variables are only populated by the server, and will be ignored when sending a request.

    :ivar id: Fully qualified resource Id for the resource.
    :vartype id: str
    :ivar name: The name of the resource.
    :vartype name: str
    :ivar type: The type of the resource - e.g. "Microsoft.SignalRService/SignalR".
    :vartype type: str
    """

    _validation = {
        'id': {'readonly': True},
        'name': {'readonly': True},
        'type': {'readonly': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(Resource, self).__init__(**kwargs)
        self.id = None
        self.name = None
        self.type = None


class ProxyResource(Resource):
    """The resource model definition for a ARM proxy resource. It will have everything other than required location and tags.

    Variables are only populated by the server, and will be ignored when sending a request.

    :ivar id: Fully qualified resource Id for the resource.
    :vartype id: str
    :ivar name: The name of the resource.
    :vartype name: str
    :ivar type: The type of the resource - e.g. "Microsoft.SignalRService/SignalR".
    :vartype type: str
    """

    _validation = {
        'id': {'readonly': True},
        'name': {'readonly': True},
        'type': {'readonly': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(ProxyResource, self).__init__(**kwargs)


class PrivateEndpointConnection(ProxyResource):
    """A private endpoint connection to an azure resource.

    Variables are only populated by the server, and will be ignored when sending a request.

    :ivar id: Fully qualified resource Id for the resource.
    :vartype id: str
    :ivar name: The name of the resource.
    :vartype name: str
    :ivar type: The type of the resource - e.g. "Microsoft.SignalRService/SignalR".
    :vartype type: str
    :ivar system_data: Metadata pertaining to creation and last modification of the resource.
    :vartype system_data: ~azure.mgmt.webpubsub.models.SystemData
    :ivar provisioning_state: Provisioning state of the private endpoint connection. Possible
     values include: "Unknown", "Succeeded", "Failed", "Canceled", "Running", "Creating",
     "Updating", "Deleting", "Moving".
    :vartype provisioning_state: str or ~azure.mgmt.webpubsub.models.ProvisioningState
    :param private_endpoint: Private endpoint associated with the private endpoint connection.
    :type private_endpoint: ~azure.mgmt.webpubsub.models.PrivateEndpoint
    :ivar group_ids: Group IDs.
    :vartype group_ids: list[str]
    :param private_link_service_connection_state: Connection state.
    :type private_link_service_connection_state:
     ~azure.mgmt.webpubsub.models.PrivateLinkServiceConnectionState
    """

    _validation = {
        'id': {'readonly': True},
        'name': {'readonly': True},
        'type': {'readonly': True},
        'system_data': {'readonly': True},
        'provisioning_state': {'readonly': True},
        'group_ids': {'readonly': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'system_data': {'key': 'systemData', 'type': 'SystemData'},
        'provisioning_state': {'key': 'properties.provisioningState', 'type': 'str'},
        'private_endpoint': {'key': 'properties.privateEndpoint', 'type': 'PrivateEndpoint'},
        'group_ids': {'key': 'properties.groupIds', 'type': '[str]'},
        'private_link_service_connection_state': {'key': 'properties.privateLinkServiceConnectionState', 'type': 'PrivateLinkServiceConnectionState'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(PrivateEndpointConnection, self).__init__(**kwargs)
        self.system_data = None
        self.provisioning_state = None
        self.private_endpoint = kwargs.get('private_endpoint', None)
        self.group_ids = None
        self.private_link_service_connection_state = kwargs.get('private_link_service_connection_state', None)


class PrivateEndpointConnectionList(msrest.serialization.Model):
    """A list of private endpoint connections.

    :param value: The list of the private endpoint connections.
    :type value: list[~azure.mgmt.webpubsub.models.PrivateEndpointConnection]
    :param next_link: Request URL that can be used to query next page of private endpoint
     connections. Returned when the total number of requested private endpoint connections exceed
     maximum page size.
    :type next_link: str
    """

    _attribute_map = {
        'value': {'key': 'value', 'type': '[PrivateEndpointConnection]'},
        'next_link': {'key': 'nextLink', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(PrivateEndpointConnectionList, self).__init__(**kwargs)
        self.value = kwargs.get('value', None)
        self.next_link = kwargs.get('next_link', None)


class PrivateLinkResource(ProxyResource):
    """Private link resource.

    Variables are only populated by the server, and will be ignored when sending a request.

    :ivar id: Fully qualified resource Id for the resource.
    :vartype id: str
    :ivar name: The name of the resource.
    :vartype name: str
    :ivar type: The type of the resource - e.g. "Microsoft.SignalRService/SignalR".
    :vartype type: str
    :param group_id: Group Id of the private link resource.
    :type group_id: str
    :param required_members: Required members of the private link resource.
    :type required_members: list[str]
    :param required_zone_names: Required private DNS zone names.
    :type required_zone_names: list[str]
    :param shareable_private_link_resource_types: The list of resources that are onboarded to
     private link service.
    :type shareable_private_link_resource_types:
     list[~azure.mgmt.webpubsub.models.ShareablePrivateLinkResourceType]
    """

    _validation = {
        'id': {'readonly': True},
        'name': {'readonly': True},
        'type': {'readonly': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'group_id': {'key': 'properties.groupId', 'type': 'str'},
        'required_members': {'key': 'properties.requiredMembers', 'type': '[str]'},
        'required_zone_names': {'key': 'properties.requiredZoneNames', 'type': '[str]'},
        'shareable_private_link_resource_types': {'key': 'properties.shareablePrivateLinkResourceTypes', 'type': '[ShareablePrivateLinkResourceType]'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(PrivateLinkResource, self).__init__(**kwargs)
        self.group_id = kwargs.get('group_id', None)
        self.required_members = kwargs.get('required_members', None)
        self.required_zone_names = kwargs.get('required_zone_names', None)
        self.shareable_private_link_resource_types = kwargs.get('shareable_private_link_resource_types', None)


class PrivateLinkResourceList(msrest.serialization.Model):
    """Contains a list of PrivateLinkResource and a possible link to query more results.

    :param value: List of PrivateLinkResource.
    :type value: list[~azure.mgmt.webpubsub.models.PrivateLinkResource]
    :param next_link: The URL the client should use to fetch the next page (per server side
     paging).
     It's null for now, added for future use.
    :type next_link: str
    """

    _attribute_map = {
        'value': {'key': 'value', 'type': '[PrivateLinkResource]'},
        'next_link': {'key': 'nextLink', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(PrivateLinkResourceList, self).__init__(**kwargs)
        self.value = kwargs.get('value', None)
        self.next_link = kwargs.get('next_link', None)


class PrivateLinkServiceConnectionState(msrest.serialization.Model):
    """Connection state of the private endpoint connection.

    :param status: Indicates whether the connection has been Approved/Rejected/Removed by the owner
     of the service. Possible values include: "Pending", "Approved", "Rejected", "Disconnected".
    :type status: str or ~azure.mgmt.webpubsub.models.PrivateLinkServiceConnectionStatus
    :param description: The reason for approval/rejection of the connection.
    :type description: str
    :param actions_required: A message indicating if changes on the service provider require any
     updates on the consumer.
    :type actions_required: str
    """

    _attribute_map = {
        'status': {'key': 'status', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'actions_required': {'key': 'actionsRequired', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(PrivateLinkServiceConnectionState, self).__init__(**kwargs)
        self.status = kwargs.get('status', None)
        self.description = kwargs.get('description', None)
        self.actions_required = kwargs.get('actions_required', None)


class RegenerateKeyParameters(msrest.serialization.Model):
    """Parameters describes the request to regenerate access keys.

    :param key_type: The keyType to regenerate. Must be either 'primary' or
     'secondary'(case-insensitive). Possible values include: "Primary", "Secondary", "Salt".
    :type key_type: str or ~azure.mgmt.webpubsub.models.KeyType
    """

    _attribute_map = {
        'key_type': {'key': 'keyType', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(RegenerateKeyParameters, self).__init__(**kwargs)
        self.key_type = kwargs.get('key_type', None)


class ResourceLogCategory(msrest.serialization.Model):
    """Resource log category configuration of a Microsoft.SignalRService resource.

    :param name: Gets or sets the resource log category's name.
     Available values: ConnectivityLogs, MessagingLogs.
     Case insensitive.
    :type name: str
    :param enabled: Indicates whether or the resource log category is enabled.
     Available values: true, false.
     Case insensitive.
    :type enabled: str
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'enabled': {'key': 'enabled', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(ResourceLogCategory, self).__init__(**kwargs)
        self.name = kwargs.get('name', None)
        self.enabled = kwargs.get('enabled', None)


class ResourceLogConfiguration(msrest.serialization.Model):
    """Resource log configuration of a Microsoft.SignalRService resource.

    :param categories: Gets or sets the list of category configurations.
    :type categories: list[~azure.mgmt.webpubsub.models.ResourceLogCategory]
    """

    _attribute_map = {
        'categories': {'key': 'categories', 'type': '[ResourceLogCategory]'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(ResourceLogConfiguration, self).__init__(**kwargs)
        self.categories = kwargs.get('categories', None)


class ResourceSku(msrest.serialization.Model):
    """The billing information of the resource.

    Variables are only populated by the server, and will be ignored when sending a request.

    All required parameters must be populated in order to send to Azure.

    :param name: Required. The name of the SKU. Required.
    
     Allowed values: Standard_S1, Free_F1.
    :type name: str
    :param tier: Optional tier of this particular SKU. 'Standard' or 'Free'.
    
     ``Basic`` is deprecated, use ``Standard`` instead. Possible values include: "Free", "Basic",
     "Standard", "Premium".
    :type tier: str or ~azure.mgmt.webpubsub.models.WebPubSubSkuTier
    :ivar size: Not used. Retained for future use.
    :vartype size: str
    :ivar family: Not used. Retained for future use.
    :vartype family: str
    :param capacity: Optional, integer. The unit count of the resource. 1 by default.
    
     If present, following values are allowed:
         Free: 1
         Standard: 1,2,5,10,20,50,100.
    :type capacity: int
    """

    _validation = {
        'name': {'required': True},
        'size': {'readonly': True},
        'family': {'readonly': True},
    }

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'tier': {'key': 'tier', 'type': 'str'},
        'size': {'key': 'size', 'type': 'str'},
        'family': {'key': 'family', 'type': 'str'},
        'capacity': {'key': 'capacity', 'type': 'int'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(ResourceSku, self).__init__(**kwargs)
        self.name = kwargs['name']
        self.tier = kwargs.get('tier', None)
        self.size = None
        self.family = None
        self.capacity = kwargs.get('capacity', None)


class ServiceSpecification(msrest.serialization.Model):
    """An object that describes a specification.

    :param metric_specifications: Specifications of the Metrics for Azure Monitoring.
    :type metric_specifications: list[~azure.mgmt.webpubsub.models.MetricSpecification]
    :param log_specifications: Specifications of the Logs for Azure Monitoring.
    :type log_specifications: list[~azure.mgmt.webpubsub.models.LogSpecification]
    """

    _attribute_map = {
        'metric_specifications': {'key': 'metricSpecifications', 'type': '[MetricSpecification]'},
        'log_specifications': {'key': 'logSpecifications', 'type': '[LogSpecification]'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(ServiceSpecification, self).__init__(**kwargs)
        self.metric_specifications = kwargs.get('metric_specifications', None)
        self.log_specifications = kwargs.get('log_specifications', None)


class ShareablePrivateLinkResourceProperties(msrest.serialization.Model):
    """Describes the properties of a resource type that has been onboarded to private link service.

    :param description: The description of the resource type that has been onboarded to private
     link service.
    :type description: str
    :param group_id: The resource provider group id for the resource that has been onboarded to
     private link service.
    :type group_id: str
    :param type: The resource provider type for the resource that has been onboarded to private
     link service.
    :type type: str
    """

    _attribute_map = {
        'description': {'key': 'description', 'type': 'str'},
        'group_id': {'key': 'groupId', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(ShareablePrivateLinkResourceProperties, self).__init__(**kwargs)
        self.description = kwargs.get('description', None)
        self.group_id = kwargs.get('group_id', None)
        self.type = kwargs.get('type', None)


class ShareablePrivateLinkResourceType(msrest.serialization.Model):
    """Describes a  resource type that has been onboarded to private link service.

    :param name: The name of the resource type that has been onboarded to private link service.
    :type name: str
    :param properties: Describes the properties of a resource type that has been onboarded to
     private link service.
    :type properties: ~azure.mgmt.webpubsub.models.ShareablePrivateLinkResourceProperties
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'properties': {'key': 'properties', 'type': 'ShareablePrivateLinkResourceProperties'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(ShareablePrivateLinkResourceType, self).__init__(**kwargs)
        self.name = kwargs.get('name', None)
        self.properties = kwargs.get('properties', None)


class SharedPrivateLinkResource(ProxyResource):
    """Describes a Shared Private Link Resource.

    Variables are only populated by the server, and will be ignored when sending a request.

    :ivar id: Fully qualified resource Id for the resource.
    :vartype id: str
    :ivar name: The name of the resource.
    :vartype name: str
    :ivar type: The type of the resource - e.g. "Microsoft.SignalRService/SignalR".
    :vartype type: str
    :ivar system_data: Metadata pertaining to creation and last modification of the resource.
    :vartype system_data: ~azure.mgmt.webpubsub.models.SystemData
    :param group_id: The group id from the provider of resource the shared private link resource is
     for.
    :type group_id: str
    :param private_link_resource_id: The resource id of the resource the shared private link
     resource is for.
    :type private_link_resource_id: str
    :ivar provisioning_state: Provisioning state of the shared private link resource. Possible
     values include: "Unknown", "Succeeded", "Failed", "Canceled", "Running", "Creating",
     "Updating", "Deleting", "Moving".
    :vartype provisioning_state: str or ~azure.mgmt.webpubsub.models.ProvisioningState
    :param request_message: The request message for requesting approval of the shared private link
     resource.
    :type request_message: str
    :ivar status: Status of the shared private link resource. Possible values include: "Pending",
     "Approved", "Rejected", "Disconnected", "Timeout".
    :vartype status: str or ~azure.mgmt.webpubsub.models.SharedPrivateLinkResourceStatus
    """

    _validation = {
        'id': {'readonly': True},
        'name': {'readonly': True},
        'type': {'readonly': True},
        'system_data': {'readonly': True},
        'provisioning_state': {'readonly': True},
        'status': {'readonly': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'system_data': {'key': 'systemData', 'type': 'SystemData'},
        'group_id': {'key': 'properties.groupId', 'type': 'str'},
        'private_link_resource_id': {'key': 'properties.privateLinkResourceId', 'type': 'str'},
        'provisioning_state': {'key': 'properties.provisioningState', 'type': 'str'},
        'request_message': {'key': 'properties.requestMessage', 'type': 'str'},
        'status': {'key': 'properties.status', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(SharedPrivateLinkResource, self).__init__(**kwargs)
        self.system_data = None
        self.group_id = kwargs.get('group_id', None)
        self.private_link_resource_id = kwargs.get('private_link_resource_id', None)
        self.provisioning_state = None
        self.request_message = kwargs.get('request_message', None)
        self.status = None


class SharedPrivateLinkResourceList(msrest.serialization.Model):
    """A list of shared private link resources.

    :param value: The list of the shared private link resources.
    :type value: list[~azure.mgmt.webpubsub.models.SharedPrivateLinkResource]
    :param next_link: Request URL that can be used to query next page of private endpoint
     connections. Returned when the total number of requested private endpoint connections exceed
     maximum page size.
    :type next_link: str
    """

    _attribute_map = {
        'value': {'key': 'value', 'type': '[SharedPrivateLinkResource]'},
        'next_link': {'key': 'nextLink', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(SharedPrivateLinkResourceList, self).__init__(**kwargs)
        self.value = kwargs.get('value', None)
        self.next_link = kwargs.get('next_link', None)


class SignalRServiceUsage(msrest.serialization.Model):
    """Object that describes a specific usage of the resources.

    :param id: Fully qualified ARM resource id.
    :type id: str
    :param current_value: Current value for the usage quota.
    :type current_value: long
    :param limit: The maximum permitted value for the usage quota. If there is no limit, this value
     will be -1.
    :type limit: long
    :param name: Localizable String object containing the name and a localized value.
    :type name: ~azure.mgmt.webpubsub.models.SignalRServiceUsageName
    :param unit: Representing the units of the usage quota. Possible values are: Count, Bytes,
     Seconds, Percent, CountPerSecond, BytesPerSecond.
    :type unit: str
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'current_value': {'key': 'currentValue', 'type': 'long'},
        'limit': {'key': 'limit', 'type': 'long'},
        'name': {'key': 'name', 'type': 'SignalRServiceUsageName'},
        'unit': {'key': 'unit', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(SignalRServiceUsage, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.current_value = kwargs.get('current_value', None)
        self.limit = kwargs.get('limit', None)
        self.name = kwargs.get('name', None)
        self.unit = kwargs.get('unit', None)


class SignalRServiceUsageList(msrest.serialization.Model):
    """Object that includes an array of the resource usages and a possible link for next set.

    :param value: List of the resource usages.
    :type value: list[~azure.mgmt.webpubsub.models.SignalRServiceUsage]
    :param next_link: The URL the client should use to fetch the next page (per server side
     paging).
     It's null for now, added for future use.
    :type next_link: str
    """

    _attribute_map = {
        'value': {'key': 'value', 'type': '[SignalRServiceUsage]'},
        'next_link': {'key': 'nextLink', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(SignalRServiceUsageList, self).__init__(**kwargs)
        self.value = kwargs.get('value', None)
        self.next_link = kwargs.get('next_link', None)


class SignalRServiceUsageName(msrest.serialization.Model):
    """Localizable String object containing the name and a localized value.

    :param value: The identifier of the usage.
    :type value: str
    :param localized_value: Localized name of the usage.
    :type localized_value: str
    """

    _attribute_map = {
        'value': {'key': 'value', 'type': 'str'},
        'localized_value': {'key': 'localizedValue', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(SignalRServiceUsageName, self).__init__(**kwargs)
        self.value = kwargs.get('value', None)
        self.localized_value = kwargs.get('localized_value', None)


class Sku(msrest.serialization.Model):
    """Describes an available sku.".

    Variables are only populated by the server, and will be ignored when sending a request.

    :ivar resource_type: The resource type that this object applies to.
    :vartype resource_type: str
    :ivar sku: The exact set of keys that define this sku.
    :vartype sku: ~azure.mgmt.webpubsub.models.ResourceSku
    :ivar capacity: Specifies the unit of the resource.
    :vartype capacity: ~azure.mgmt.webpubsub.models.SkuCapacity
    """

    _validation = {
        'resource_type': {'readonly': True},
        'sku': {'readonly': True},
        'capacity': {'readonly': True},
    }

    _attribute_map = {
        'resource_type': {'key': 'resourceType', 'type': 'str'},
        'sku': {'key': 'sku', 'type': 'ResourceSku'},
        'capacity': {'key': 'capacity', 'type': 'SkuCapacity'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(Sku, self).__init__(**kwargs)
        self.resource_type = None
        self.sku = None
        self.capacity = None


class SkuCapacity(msrest.serialization.Model):
    """Describes scaling information of a sku.

    Variables are only populated by the server, and will be ignored when sending a request.

    :ivar minimum: The lowest permitted capacity for this resource.
    :vartype minimum: int
    :ivar maximum: The highest permitted capacity for this resource.
    :vartype maximum: int
    :ivar default: The default capacity.
    :vartype default: int
    :ivar allowed_values: Allows capacity value list.
    :vartype allowed_values: list[int]
    :ivar scale_type: The scale type applicable to the sku. Possible values include: "None",
     "Manual", "Automatic".
    :vartype scale_type: str or ~azure.mgmt.webpubsub.models.ScaleType
    """

    _validation = {
        'minimum': {'readonly': True},
        'maximum': {'readonly': True},
        'default': {'readonly': True},
        'allowed_values': {'readonly': True},
        'scale_type': {'readonly': True},
    }

    _attribute_map = {
        'minimum': {'key': 'minimum', 'type': 'int'},
        'maximum': {'key': 'maximum', 'type': 'int'},
        'default': {'key': 'default', 'type': 'int'},
        'allowed_values': {'key': 'allowedValues', 'type': '[int]'},
        'scale_type': {'key': 'scaleType', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(SkuCapacity, self).__init__(**kwargs)
        self.minimum = None
        self.maximum = None
        self.default = None
        self.allowed_values = None
        self.scale_type = None


class SkuList(msrest.serialization.Model):
    """The list skus operation response.

    Variables are only populated by the server, and will be ignored when sending a request.

    :ivar value: The list of skus available for the resource.
    :vartype value: list[~azure.mgmt.webpubsub.models.Sku]
    :ivar next_link: The URL the client should use to fetch the next page (per server side paging).
     It's null for now, added for future use.
    :vartype next_link: str
    """

    _validation = {
        'value': {'readonly': True},
        'next_link': {'readonly': True},
    }

    _attribute_map = {
        'value': {'key': 'value', 'type': '[Sku]'},
        'next_link': {'key': 'nextLink', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(SkuList, self).__init__(**kwargs)
        self.value = None
        self.next_link = None


class SystemData(msrest.serialization.Model):
    """Metadata pertaining to creation and last modification of the resource.

    :param created_by: The identity that created the resource.
    :type created_by: str
    :param created_by_type: The type of identity that created the resource. Possible values
     include: "User", "Application", "ManagedIdentity", "Key".
    :type created_by_type: str or ~azure.mgmt.webpubsub.models.CreatedByType
    :param created_at: The timestamp of resource creation (UTC).
    :type created_at: ~datetime.datetime
    :param last_modified_by: The identity that last modified the resource.
    :type last_modified_by: str
    :param last_modified_by_type: The type of identity that last modified the resource. Possible
     values include: "User", "Application", "ManagedIdentity", "Key".
    :type last_modified_by_type: str or ~azure.mgmt.webpubsub.models.CreatedByType
    :param last_modified_at: The timestamp of resource last modification (UTC).
    :type last_modified_at: ~datetime.datetime
    """

    _attribute_map = {
        'created_by': {'key': 'createdBy', 'type': 'str'},
        'created_by_type': {'key': 'createdByType', 'type': 'str'},
        'created_at': {'key': 'createdAt', 'type': 'iso-8601'},
        'last_modified_by': {'key': 'lastModifiedBy', 'type': 'str'},
        'last_modified_by_type': {'key': 'lastModifiedByType', 'type': 'str'},
        'last_modified_at': {'key': 'lastModifiedAt', 'type': 'iso-8601'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(SystemData, self).__init__(**kwargs)
        self.created_by = kwargs.get('created_by', None)
        self.created_by_type = kwargs.get('created_by_type', None)
        self.created_at = kwargs.get('created_at', None)
        self.last_modified_by = kwargs.get('last_modified_by', None)
        self.last_modified_by_type = kwargs.get('last_modified_by_type', None)
        self.last_modified_at = kwargs.get('last_modified_at', None)


class TrackedResource(Resource):
    """The resource model definition for a ARM tracked top level resource.

    Variables are only populated by the server, and will be ignored when sending a request.

    :ivar id: Fully qualified resource Id for the resource.
    :vartype id: str
    :ivar name: The name of the resource.
    :vartype name: str
    :ivar type: The type of the resource - e.g. "Microsoft.SignalRService/SignalR".
    :vartype type: str
    :param location: The GEO location of the resource. e.g. West US | East US | North Central US |
     South Central US.
    :type location: str
    :param tags: A set of tags. Tags of the service which is a list of key value pairs that
     describe the resource.
    :type tags: dict[str, str]
    """

    _validation = {
        'id': {'readonly': True},
        'name': {'readonly': True},
        'type': {'readonly': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'location': {'key': 'location', 'type': 'str'},
        'tags': {'key': 'tags', 'type': '{str}'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(TrackedResource, self).__init__(**kwargs)
        self.location = kwargs.get('location', None)
        self.tags = kwargs.get('tags', None)


class UpstreamAuthSettings(msrest.serialization.Model):
    """Upstream auth settings.

    :param type: Gets or sets the type of auth. None or ManagedIdentity is supported now. Possible
     values include: "None", "ManagedIdentity".
    :type type: str or ~azure.mgmt.webpubsub.models.UpstreamAuthType
    :param managed_identity: Gets or sets the managed identity settings. It's required if the auth
     type is set to ManagedIdentity.
    :type managed_identity: ~azure.mgmt.webpubsub.models.ManagedIdentitySettings
    """

    _attribute_map = {
        'type': {'key': 'type', 'type': 'str'},
        'managed_identity': {'key': 'managedIdentity', 'type': 'ManagedIdentitySettings'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(UpstreamAuthSettings, self).__init__(**kwargs)
        self.type = kwargs.get('type', None)
        self.managed_identity = kwargs.get('managed_identity', None)


class UserAssignedIdentityProperty(msrest.serialization.Model):
    """Properties of user assigned identity.

    Variables are only populated by the server, and will be ignored when sending a request.

    :ivar principal_id: Get the principal id for the user assigned identity.
    :vartype principal_id: str
    :ivar client_id: Get the client id for the user assigned identity.
    :vartype client_id: str
    """

    _validation = {
        'principal_id': {'readonly': True},
        'client_id': {'readonly': True},
    }

    _attribute_map = {
        'principal_id': {'key': 'principalId', 'type': 'str'},
        'client_id': {'key': 'clientId', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(UserAssignedIdentityProperty, self).__init__(**kwargs)
        self.principal_id = None
        self.client_id = None


class WebPubSubHub(ProxyResource):
    """A hub setting.

    Variables are only populated by the server, and will be ignored when sending a request.

    All required parameters must be populated in order to send to Azure.

    :ivar id: Fully qualified resource Id for the resource.
    :vartype id: str
    :ivar name: The name of the resource.
    :vartype name: str
    :ivar type: The type of the resource - e.g. "Microsoft.SignalRService/SignalR".
    :vartype type: str
    :ivar system_data: Metadata pertaining to creation and last modification of the resource.
    :vartype system_data: ~azure.mgmt.webpubsub.models.SystemData
    :param properties: Required. Properties of the hub setting.
    :type properties: ~azure.mgmt.webpubsub.models.WebPubSubHubProperties
    """

    _validation = {
        'id': {'readonly': True},
        'name': {'readonly': True},
        'type': {'readonly': True},
        'system_data': {'readonly': True},
        'properties': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'system_data': {'key': 'systemData', 'type': 'SystemData'},
        'properties': {'key': 'properties', 'type': 'WebPubSubHubProperties'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(WebPubSubHub, self).__init__(**kwargs)
        self.system_data = None
        self.properties = kwargs['properties']


class WebPubSubHubList(msrest.serialization.Model):
    """Hub setting list.

    Variables are only populated by the server, and will be ignored when sending a request.

    :param value: List of hub settings to this resource.
    :type value: list[~azure.mgmt.webpubsub.models.WebPubSubHub]
    :ivar next_link: The URL the client should use to fetch the next page (per server side paging).
     It's null for now, added for future use.
    :vartype next_link: str
    """

    _validation = {
        'next_link': {'readonly': True},
    }

    _attribute_map = {
        'value': {'key': 'value', 'type': '[WebPubSubHub]'},
        'next_link': {'key': 'nextLink', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(WebPubSubHubList, self).__init__(**kwargs)
        self.value = kwargs.get('value', None)
        self.next_link = None


class WebPubSubHubProperties(msrest.serialization.Model):
    """Properties of a hub.

    :param event_handlers: Event handler of a hub.
    :type event_handlers: list[~azure.mgmt.webpubsub.models.EventHandler]
    :param anonymous_connect_policy: The settings for configuring if anonymous connections are
     allowed for this hub: "allow" or "deny". Default to "deny".
    :type anonymous_connect_policy: str
    """

    _attribute_map = {
        'event_handlers': {'key': 'eventHandlers', 'type': '[EventHandler]'},
        'anonymous_connect_policy': {'key': 'anonymousConnectPolicy', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(WebPubSubHubProperties, self).__init__(**kwargs)
        self.event_handlers = kwargs.get('event_handlers', None)
        self.anonymous_connect_policy = kwargs.get('anonymous_connect_policy', "deny")


class WebPubSubKeys(msrest.serialization.Model):
    """A class represents the access keys of the resource.

    :param primary_key: The primary access key.
    :type primary_key: str
    :param secondary_key: The secondary access key.
    :type secondary_key: str
    :param primary_connection_string: Connection string constructed via the primaryKey.
    :type primary_connection_string: str
    :param secondary_connection_string: Connection string constructed via the secondaryKey.
    :type secondary_connection_string: str
    """

    _attribute_map = {
        'primary_key': {'key': 'primaryKey', 'type': 'str'},
        'secondary_key': {'key': 'secondaryKey', 'type': 'str'},
        'primary_connection_string': {'key': 'primaryConnectionString', 'type': 'str'},
        'secondary_connection_string': {'key': 'secondaryConnectionString', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(WebPubSubKeys, self).__init__(**kwargs)
        self.primary_key = kwargs.get('primary_key', None)
        self.secondary_key = kwargs.get('secondary_key', None)
        self.primary_connection_string = kwargs.get('primary_connection_string', None)
        self.secondary_connection_string = kwargs.get('secondary_connection_string', None)


class WebPubSubNetworkACLs(msrest.serialization.Model):
    """Network ACLs for the resource.

    :param default_action: Default action when no other rule matches. Possible values include:
     "Allow", "Deny".
    :type default_action: str or ~azure.mgmt.webpubsub.models.ACLAction
    :param public_network: ACL for requests from public network.
    :type public_network: ~azure.mgmt.webpubsub.models.NetworkACL
    :param private_endpoints: ACLs for requests from private endpoints.
    :type private_endpoints: list[~azure.mgmt.webpubsub.models.PrivateEndpointACL]
    """

    _attribute_map = {
        'default_action': {'key': 'defaultAction', 'type': 'str'},
        'public_network': {'key': 'publicNetwork', 'type': 'NetworkACL'},
        'private_endpoints': {'key': 'privateEndpoints', 'type': '[PrivateEndpointACL]'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(WebPubSubNetworkACLs, self).__init__(**kwargs)
        self.default_action = kwargs.get('default_action', None)
        self.public_network = kwargs.get('public_network', None)
        self.private_endpoints = kwargs.get('private_endpoints', None)


class WebPubSubResource(TrackedResource):
    """A class represent a resource.

    Variables are only populated by the server, and will be ignored when sending a request.

    :ivar id: Fully qualified resource Id for the resource.
    :vartype id: str
    :ivar name: The name of the resource.
    :vartype name: str
    :ivar type: The type of the resource - e.g. "Microsoft.SignalRService/SignalR".
    :vartype type: str
    :param location: The GEO location of the resource. e.g. West US | East US | North Central US |
     South Central US.
    :type location: str
    :param tags: A set of tags. Tags of the service which is a list of key value pairs that
     describe the resource.
    :type tags: dict[str, str]
    :param sku: The billing information of the resource.(e.g. Free, Standard).
    :type sku: ~azure.mgmt.webpubsub.models.ResourceSku
    :param identity: The managed identity response.
    :type identity: ~azure.mgmt.webpubsub.models.ManagedIdentity
    :ivar system_data: Metadata pertaining to creation and last modification of the resource.
    :vartype system_data: ~azure.mgmt.webpubsub.models.SystemData
    :ivar provisioning_state: Provisioning state of the resource. Possible values include:
     "Unknown", "Succeeded", "Failed", "Canceled", "Running", "Creating", "Updating", "Deleting",
     "Moving".
    :vartype provisioning_state: str or ~azure.mgmt.webpubsub.models.ProvisioningState
    :ivar external_ip: The publicly accessible IP of the resource.
    :vartype external_ip: str
    :ivar host_name: FQDN of the service instance.
    :vartype host_name: str
    :ivar public_port: The publicly accessible port of the resource which is designed for
     browser/client side usage.
    :vartype public_port: int
    :ivar server_port: The publicly accessible port of the resource which is designed for customer
     server side usage.
    :vartype server_port: int
    :ivar version: Version of the resource. Probably you need the same or higher version of client
     SDKs.
    :vartype version: str
    :ivar private_endpoint_connections: Private endpoint connections to the resource.
    :vartype private_endpoint_connections:
     list[~azure.mgmt.webpubsub.models.PrivateEndpointConnection]
    :ivar shared_private_link_resources: The list of shared private link resources.
    :vartype shared_private_link_resources:
     list[~azure.mgmt.webpubsub.models.SharedPrivateLinkResource]
    :param tls: TLS settings.
    :type tls: ~azure.mgmt.webpubsub.models.WebPubSubTlsSettings
    :ivar host_name_prefix: Deprecated.
    :vartype host_name_prefix: str
    :param live_trace_configuration: Live trace configuration of a Microsoft.SignalRService
     resource.
    :type live_trace_configuration: ~azure.mgmt.webpubsub.models.LiveTraceConfiguration
    :param resource_log_configuration: Resource log configuration of a Microsoft.SignalRService
     resource.
     If resourceLogConfiguration isn't null or empty, it will override options
     "EnableConnectivityLog" and "EnableMessagingLogs" in features.
     Otherwise, use options "EnableConnectivityLog" and "EnableMessagingLogs" in features.
    :type resource_log_configuration: ~azure.mgmt.webpubsub.models.ResourceLogConfiguration
    :param network_ac_ls: Network ACLs.
    :type network_ac_ls: ~azure.mgmt.webpubsub.models.WebPubSubNetworkACLs
    :param public_network_access: Enable or disable public network access. Default to "Enabled".
     When it's Enabled, network ACLs still apply.
     When it's Disabled, public network access is always disabled no matter what you set in network
     ACLs.
    :type public_network_access: str
    :param disable_local_auth: DisableLocalAuth
     Enable or disable local auth with AccessKey
     When set as true, connection with AccessKey=xxx won't work.
    :type disable_local_auth: bool
    :param disable_aad_auth: DisableLocalAuth
     Enable or disable aad auth
     When set as true, connection with AuthType=aad won't work.
    :type disable_aad_auth: bool
    """

    _validation = {
        'id': {'readonly': True},
        'name': {'readonly': True},
        'type': {'readonly': True},
        'system_data': {'readonly': True},
        'provisioning_state': {'readonly': True},
        'external_ip': {'readonly': True},
        'host_name': {'readonly': True},
        'public_port': {'readonly': True},
        'server_port': {'readonly': True},
        'version': {'readonly': True},
        'private_endpoint_connections': {'readonly': True},
        'shared_private_link_resources': {'readonly': True},
        'host_name_prefix': {'readonly': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'location': {'key': 'location', 'type': 'str'},
        'tags': {'key': 'tags', 'type': '{str}'},
        'sku': {'key': 'sku', 'type': 'ResourceSku'},
        'identity': {'key': 'identity', 'type': 'ManagedIdentity'},
        'system_data': {'key': 'systemData', 'type': 'SystemData'},
        'provisioning_state': {'key': 'properties.provisioningState', 'type': 'str'},
        'external_ip': {'key': 'properties.externalIP', 'type': 'str'},
        'host_name': {'key': 'properties.hostName', 'type': 'str'},
        'public_port': {'key': 'properties.publicPort', 'type': 'int'},
        'server_port': {'key': 'properties.serverPort', 'type': 'int'},
        'version': {'key': 'properties.version', 'type': 'str'},
        'private_endpoint_connections': {'key': 'properties.privateEndpointConnections', 'type': '[PrivateEndpointConnection]'},
        'shared_private_link_resources': {'key': 'properties.sharedPrivateLinkResources', 'type': '[SharedPrivateLinkResource]'},
        'tls': {'key': 'properties.tls', 'type': 'WebPubSubTlsSettings'},
        'host_name_prefix': {'key': 'properties.hostNamePrefix', 'type': 'str'},
        'live_trace_configuration': {'key': 'properties.liveTraceConfiguration', 'type': 'LiveTraceConfiguration'},
        'resource_log_configuration': {'key': 'properties.resourceLogConfiguration', 'type': 'ResourceLogConfiguration'},
        'network_ac_ls': {'key': 'properties.networkACLs', 'type': 'WebPubSubNetworkACLs'},
        'public_network_access': {'key': 'properties.publicNetworkAccess', 'type': 'str'},
        'disable_local_auth': {'key': 'properties.disableLocalAuth', 'type': 'bool'},
        'disable_aad_auth': {'key': 'properties.disableAadAuth', 'type': 'bool'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(WebPubSubResource, self).__init__(**kwargs)
        self.sku = kwargs.get('sku', None)
        self.identity = kwargs.get('identity', None)
        self.system_data = None
        self.provisioning_state = None
        self.external_ip = None
        self.host_name = None
        self.public_port = None
        self.server_port = None
        self.version = None
        self.private_endpoint_connections = None
        self.shared_private_link_resources = None
        self.tls = kwargs.get('tls', None)
        self.host_name_prefix = None
        self.live_trace_configuration = kwargs.get('live_trace_configuration', None)
        self.resource_log_configuration = kwargs.get('resource_log_configuration', None)
        self.network_ac_ls = kwargs.get('network_ac_ls', None)
        self.public_network_access = kwargs.get('public_network_access', "Enabled")
        self.disable_local_auth = kwargs.get('disable_local_auth', False)
        self.disable_aad_auth = kwargs.get('disable_aad_auth', False)


class WebPubSubResourceList(msrest.serialization.Model):
    """Object that includes an array of resources and a possible link for next set.

    :param value: List of the resources.
    :type value: list[~azure.mgmt.webpubsub.models.WebPubSubResource]
    :param next_link: The URL the client should use to fetch the next page (per server side
     paging).
     It's null for now, added for future use.
    :type next_link: str
    """

    _attribute_map = {
        'value': {'key': 'value', 'type': '[WebPubSubResource]'},
        'next_link': {'key': 'nextLink', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(WebPubSubResourceList, self).__init__(**kwargs)
        self.value = kwargs.get('value', None)
        self.next_link = kwargs.get('next_link', None)


class WebPubSubTlsSettings(msrest.serialization.Model):
    """TLS settings for the resource.

    :param client_cert_enabled: Request client certificate during TLS handshake if enabled.
    :type client_cert_enabled: bool
    """

    _attribute_map = {
        'client_cert_enabled': {'key': 'clientCertEnabled', 'type': 'bool'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(WebPubSubTlsSettings, self).__init__(**kwargs)
        self.client_cert_enabled = kwargs.get('client_cert_enabled', True)
